TransitEdge

Struct TransitEdge 

pub struct TransitEdge<T: CoordNum> {
    pub id: EdgeId,
    pub source: NodeId,
    pub target: NodeId,
    pub length: T,
    pub path: LineString<T>,
}
Structure representing a connection between two TransitNode instances.

Each edge has a unique identifier and a path represented as a LineString. The LineString type T is generic and can be any type that implements the CoordNum trait.

Examples

use geo::{coord, LineString};
use transit_grid::core::TransitEdge;

let edge = TransitEdge {
    id: 1,
    source: 1,
    target: 2,
    length: 1.0,
    path: LineString(vec![coord! { x: 0.0, y: 0.0 }, coord! { x: 1.0, y: 1.0 }]),
};
assert_eq!(edge.id, 1);
assert_eq!(edge.source, 1);
assert_eq!(edge.target, 2);
assert_eq!(edge.path, LineString(vec![coord! { x: 0.0, y: 0.0 }, coord! { x: 1.0, y: 1.0 }]));

Fields

id: EdgeId

A unique identifier for the edge.

source: NodeId

The identifier of the node where the edge starts.

target: NodeId

The identifier of the node where the edge ends.

length: T

The length of the edge.

path: LineString<T>

The path of the edge, represented as a LineString.